@@ -358,7 +358,7 @@ class InformationModel(Resource):
         self: InformationModel,
         format: str = "turtle",
         encoding: Optional[str] = "utf-8",
-    ) -> str:
+    ) -> bytes:
         """Maps the information model to rdf.
 
         Available formats:
@@ -371,7 +371,7 @@ class InformationModel(Resource):
             encoding (str): the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -769,7 +769,9 @@ class ModelElement(ABC):
         self._description = description
 
     @abstractmethod
-    def to_rdf(self, format: str = "turtle", encoding: Optional[str] = "utf-8") -> str:
+    def to_rdf(
+        self, format: str = "turtle", encoding: Optional[str] = "utf-8"
+    ) -> bytes:
         """Maps the modelelement to rdf.
 
         Args:
@@ -1034,7 +1036,9 @@ class ModelProperty(ABC):
         self._sequence_number = sequence_number
 
     @abstractmethod
-    def to_rdf(self, format: str = "turtle", encoding: Optional[str] = "utf-8") -> str:
+    def to_rdf(
+        self, format: str = "turtle", encoding: Optional[str] = "utf-8"
+    ) -> bytes:
         """Maps the property to rdf.
 
         Args:
@@ -1216,7 +1220,7 @@ class Role(ModelProperty):
 
     def to_rdf(
         self: Role, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
+    ) -> bytes:
         """Maps the role to rdf.
 
         Args:
@@ -1224,7 +1228,7 @@ class Role(ModelProperty):
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -1287,7 +1291,7 @@ class ObjectType(ModelElement):
 
     def to_rdf(
         self: ObjectType, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
+    ) -> bytes:
         """Maps the object type to rdf.
 
         Args:
@@ -1295,7 +1299,7 @@ class ObjectType(ModelElement):
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -1447,15 +1451,15 @@ class SimpleType(ModelElement):
 
     def to_rdf(
         self: SimpleType, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the object type to rdf.
+    ) -> bytes:
+        """Maps the simple type to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -1545,15 +1549,15 @@ class Composition(ModelProperty):
 
     def to_rdf(
         self: Composition, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the role to rdf.
+    ) -> bytes:
+        """Maps the composition to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -1627,15 +1631,15 @@ class Collection(ModelProperty):
 
     def to_rdf(
         self: Collection, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the role to rdf.
+    ) -> bytes:
+        """Maps the collection to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -1711,15 +1715,15 @@ class Association(ModelProperty):
 
     def to_rdf(
         self: Association, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the role to rdf.
+    ) -> bytes:
+        """Maps the association to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -1796,15 +1800,15 @@ class Choice(ModelProperty):
 
     def to_rdf(
         self: Choice, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the role to rdf.
+    ) -> bytes:
+        """Maps the choice to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -1921,15 +1925,15 @@ class Attribute(ModelProperty):
 
     def to_rdf(
         self: Attribute, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the role to rdf.
+    ) -> bytes:
+        """Maps the attribute to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -2072,15 +2076,15 @@ class Specialization(ModelProperty):
 
     def to_rdf(
         self: Specialization, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the role to rdf.
+    ) -> bytes:
+        """Maps the specialization to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -2156,7 +2160,7 @@ class Realization(ModelProperty):
 
     def to_rdf(
         self: Realization, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
+    ) -> bytes:
         """Maps the realization to rdf.
 
         Args:
@@ -2164,7 +2168,7 @@ class Realization(ModelProperty):
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -2242,15 +2246,15 @@ class Abstraction(ModelProperty):
 
     def to_rdf(
         self: Abstraction, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the role to rdf.
+    ) -> bytes:
+        """Maps the abstraction to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -2315,7 +2319,7 @@ class DataType(ModelElement):
 
     def to_rdf(
         self: DataType, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
+    ) -> bytes:
         """Maps the data type to rdf.
 
         Args:
@@ -2323,7 +2327,7 @@ class DataType(ModelElement):
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -2362,15 +2366,15 @@ class RootObjectType(ModelElement):
 
     def to_rdf(
         self: RootObjectType, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the data type to rdf.
+    ) -> bytes:
+        """Maps the root object type type to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -2432,7 +2436,7 @@ class CodeList(ModelElement):
 
     def to_rdf(
         self: CodeList, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
+    ) -> bytes:
         """Maps the code list to rdf.
 
         Args:
@@ -2440,7 +2444,7 @@ class CodeList(ModelElement):
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -2714,7 +2718,7 @@ class CodeElement:
 
     def to_rdf(
         self: CodeElement, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
+    ) -> bytes:
         """Maps the code element to rdf.
 
         Args:
@@ -2722,7 +2726,7 @@ class CodeElement:
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
@@ -2984,15 +2988,15 @@ class Note(ModelProperty):
 
     def to_rdf(
         self: Note, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> str:
-        """Maps the role to rdf.
+    ) -> bytes:
+        """Maps the note to rdf.
 
         Args:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
         Returns:
-            a rdf serialization as a string according to format.
+            a rdf serialization as a string according to format encoded as bytes.
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
